#!/usr/bin/env bash
# This program starts a child process of model one alignment
# It takes  ? Parameters
echo "---------------------------------------------------------------"
echo "Usage of this script:"
echo "runHMMChild.sh <config> <output_t> <output_a> <output_hmm> <run> <signal> <log> <prev_tmodel> [prev_model] [prev_hmm]"
echo "1. <config> is the configure template, "
echo "2. <output_t> is the path of the difference file for"
echo "3. <output_a> is the path of the count table for align table"
echo "4. <output_hmm> is the path of the count table for hmm table"
echo "5. <run> should be integer to indicate which run it is"
echo "6. <signal> is the file which I will touch when finished training"
echo "7. <log> is the log file which I record everything"
echo "8. <prev_tmodel> the t model from last step"
echo "9. [prev_amodel] is the previous a model "
echo "10.[prev_hmodel] is the previous HMM table"
echo "---------------------------------------------------------------"
echo 
echo 
if [ $# -lt "8" ];
then
	echo " NO! I need your command!"
	exit 1
fi

TEMPL=$1
OTTABLE=$2
OATABLE=$3
OHTABLE=$4
RUN=$5
SIGDIR=$6
LOGDIR=$7
PREVTMODEL=$8
PREVAMODEL=$9
PREVHMODEL=${10}

if [ -e $PWD/defines.inc ];
then
	source $PWD/defines.inc
else
	HMM_EXEC=/SMT/giza/view_source/newgiza/src/para/hmm_align
fi

if [ -x $HMM_EXEC ];
then
	echo " Using executable " $HMM_EXEC 
else
	echo " The execution file " $HMM_EXEC " cannot be executed dude"
	echo " set environment HMM_EXEC to get me run!"
	exit 1
fi

# Here is the configure file we are going to write
CONF=/tmp/`basename ${TEMPL}`.$$.${RUN}.hmm.gizaconf
# We need to test whether the environment is OK
if [ -r ${TEMPL} ]; # is template exists?
then
	echo "... Checking template at " ${TEMPL}
	echo " GOOD, I am now copying the template to where we will start"
	cat ${TEMPL} > $CONF
	# test ?
	echo " The initial configure is written to file " $CONF
else
	echo " NO! The template cannot be read! "
	exit 1
fi

echo "...Checking previous t model" ${PREVTMODEL}
if [ -r ${PREVTMODEL} ]; #is previous t model exists
then
	echo "OK"
	echo "prevtmodel " ${PREVTMODEL} >> $CONF
else
	echo "NO, tell me where is the previous t model"
fi

# Now add the lines we needs

if [ ${RUN} != "1" ]; 
then
	if [ $# -lt "10" ]; 
	then
		echo "NO! If you want me to run a second round, tell me where to start"
		exit 1
	else
		echo "prevamodel " ${PREVAMODEL} >> $CONF
		echo "prevhmodel " ${PREVHMODEL} >> $CONF
	fi
fi

echo "cm2 " ${RUN} >> $CONF
echo "outputdiff" ${OTTABLE} >> $CONF
echo "outputacounttable" ${OATABLE} >> $CONF
echo "outputhcounttable" ${OHTABLE} >> $CONF
echo "o" $ALIGN_DIR/`basename ${SIGDIR}` >> $CONF

# Now we have everything, start!
rm -f ${SIGDIR}
rm -f ${SIGDIR}.failed
rm -f ${SIGDIR}.starting
touch ${SIGDIR}.running
echo $CONF
if $HMM_EXEC $CONF &> ${LOGDIR} ;
then
	echo " Yeah! we finish, please tell my mom at" ${SIGDIR}
	touch ${SIGDIR}
else
	echo " Something is wrong, see " ${LOGDIR} ", I wrote something"
	touch ${SIGDIR}.failed
	# When mother see this, do something to save me
fi

rm -f ${SIGDIR}.running




